==> etchibbs-spiral-1.1.1.tar.gz: etchibbs-spiral/upload_icon.php <==
<?php
/* vim600: et ts=4 sts=4 sw=4 fdm=marker
 *
 * EtchiBBS UTF-8 - Gallery Web Board
 * Copyright (C) 2004 EtchiBoard Project
 * 
 * See LICENSE for license condition.
 *
 * http://etchibbs.kldp.net
 * $Id: upload_icon.php,v 1.9 2004/01/22 18:06:35 lseeker Exp $
*/

require 'lib/admin.inc'; // 관리자 환경설정
DB::close($dbconn);

include "skin/{$admin_data['skin']}/style.php"; // 스킨
include 'lib/message.inc'; // 메시지 function

if ($_FILES['iconfile']['tmp_name']) {
    // 파일명으로 부적절한 부분은 변경.. (1.0.5)
    $iconfile_name = $_FILES['iconfile']['name'];
    $iconfile_name = str_replace('\\', '_', $iconfile_name);
    $iconfile_name = str_replace('?', '_', $iconfile_name);
    $iconfile_name = str_replace('"', '_', $iconfile_name);
    $iconfile_name = str_replace('/', '_', $iconfile_name);
    $iconfile_name = str_replace(':', '_', $iconfile_name);
    $iconfile_name = str_replace('*', '_', $iconfile_name); // 이거랑 그 친구들.. 귀찮아서 그냥 넣음..-_-
    $iconfile_name = str_replace('<', '_', $iconfile_name);
    $iconfile_name = str_replace('>', '_', $iconfile_name);
    $iconfile_name = str_replace('|', '_', $iconfile_name);
    $iconfile_name = str_replace('#', '_', $iconfile_name); // ?
    $iconfile_name = str_replace('%', '_', $iconfile_name); // ??
}

/* {{{ 오류 처리 */
if (!$admin['login']) {
    // 로그인 상태가 아니라면
    PrintMessage("<br>관리자 쿠키를 찾을 수 없습니다.", "error");
    exit;
} elseif (!file_exists($_FILES['iconfile']['tmp_name'])) {
    PrintMessage("아이콘 파일을 전달받지 못하였습니다.", "error");
    exit;
} elseif (file_exists('db/ico/' . $iconfile_name) || $iconfile_name == "none.jpg") {
    PrintMessage("이미 같은 이름의 아이콘이 존재합니다.", "error");
    exit;
}
/* }}} */

// 아이콘 복사/권한변경/임시파일 삭제
umask(0111);
move_uploaded_file($_FILES['iconfile']['tmp_name'], 'db/ico/' . $iconfile_name)
or die(PrintMessage("{$iconfile_name} 파일을 업로드하지 못했습니다.<br />db/ico 디렉토리의 권한을 확인해 주세요.", "error"));

$path = substr($_SERVER['PHP_SELF'], 0, strrpos($_SERVER['PHP_SELF'], '/'));

header('HTTP/1.1 303 See Other');
header('Location: http://' . $_SERVER['HTTP_HOST'] . $path . '/iconman.php');
header('Content-Type: text/html; charset=UTF-8');
?>
<!DOCTYPE HTML PUBLIC "-//IETF//DTD HTML 2.0//EN">
<html>
<head>
 <title>Redirection</title>
 <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
 <meta http-equiv="refresh" content="0; url=iconman.php">
</head>
<body>
 <p>
 이 화면이 보인다면, <a href="iconman.php">여기</a>를 클릭하십시오.<br />
 Please click <a href="iconman.php">here</a>.
 </p>
</body>
</html>

==> etchibbs-spiral-1.2.0.tar.gz: etchibbs-spiral/upload_icon.php <==
<?php
/* vim600: et ts=4 sts=4 sw=4 fdm=marker
 *
 * EtchiBBS UTF-8 - Gallery Web Board
 * Copyright (C) 2004 EtchiBoard Project
 * 
 * See LICENSE for license condition.
 *
 * http://etchibbs.kldp.net
 * $Id: upload_icon.php,v 1.15 2004/03/16 02:25:55 lseeker Exp $
*/

require 'lib/common.php';
$DB->close();

if ($_FILES['iconfile']['tmp_name']) {
    // 파일명으로 부적절한 부분은 변경.. (1.0.5)
    $iconfile_name = $_FILES['iconfile']['name'];
    $iconfile_name = str_replace('\\', '_', $iconfile_name);
    $iconfile_name = str_replace('?', '_', $iconfile_name);
    $iconfile_name = str_replace('"', '_', $iconfile_name);
    $iconfile_name = str_replace('/', '_', $iconfile_name);
    $iconfile_name = str_replace(':', '_', $iconfile_name);
    $iconfile_name = str_replace('*', '_', $iconfile_name); // 이거랑 그 친구들.. 귀찮아서 그냥 넣음..-_-
    $iconfile_name = str_replace('<', '_', $iconfile_name);
    $iconfile_name = str_replace('>', '_', $iconfile_name);
    $iconfile_name = str_replace('|', '_', $iconfile_name);
    $iconfile_name = str_replace('#', '_', $iconfile_name); // ?
    $iconfile_name = str_replace('%', '_', $iconfile_name); // ??
}

/* {{{ 오류 처리 */
if (!$admin['login']) error_exit('관리자 쿠키를 찾을 수 없습니다.', FALSE);

if(!file_exists($_FILES['iconfile']['tmp_name'])) error_exit('아이콘 파일을 전달받지 못하였습니다.', FALSE);

if (file_exists('db/ico/' . $iconfile_name) || $iconfile_name == 'none.jpg') error_exit('이미 같은 이름의 아이콘이 존재합니다.', FALSE);
/* }}} */

// 아이콘 복사/권한변경/임시파일 삭제
umask(0111);
if (move_uploaded_file($_FILES['iconfile']['tmp_name'], 'db/ico/' . $iconfile_name) === FALSE) error_exit("{$iconfile_name} 파일을 업로드하지 못했습니다.<br />db/ico 디렉토리의 권한을 확인해 주세요.", FALSE);

header('HTTP/1.1 303 See Other');
$redirect_to = 'iconman.php';
include 'lib/redirect.php';
?>
